from .StructuralDampingByFrequencyComponent import StructuralDampingByFrequencyComponent


class StructuralDampingByFrequencyComponentArray(
    list[StructuralDampingByFrequencyComponent]
):
    def findAt(self):
        pass
